@@ -1,8 +1,4 @@
 ############# preparations ################
-.onLoad <- function(lib, pkg) {
-    require("methods", character = TRUE, quietly = TRUE)
-}
-
 if(!isGeneric("robloxbioc")){
     setGeneric("robloxbioc", 
         function(x, ...) standardGeneric("robloxbioc"))
